EXPORTS
	?CancelReceiveEvents@RMMFAudioPolicyProxy@@QAEHXZ @ 1 NONAME ; public: int __thiscall RMMFAudioPolicyProxy::CancelReceiveEvents(void)
	?GetPlayFormat@RMMFAudioPolicyProxy@@QAEHAAV?$TPckgBuf@VTCurrentSoundFormat@RMdaDevSound@@@@@Z @ 2 NONAME ; public: int __thiscall RMMFAudioPolicyProxy::GetPlayFormat(class TPckgBuf<class RMdaDevSound::TCurrentSoundFormat> &)
	?GetPlayFormatsSupported@RMMFAudioPolicyProxy@@QAEHAAV?$TPckgBuf@VTSoundFormatsSupported@RMdaDevSound@@@@@Z @ 3 NONAME ; public: int __thiscall RMMFAudioPolicyProxy::GetPlayFormatsSupported(class TPckgBuf<class RMdaDevSound::TSoundFormatsSupported> &)
	?GetRecordFormat@RMMFAudioPolicyProxy@@QAEHAAV?$TPckgBuf@VTCurrentSoundFormat@RMdaDevSound@@@@@Z @ 4 NONAME ; public: int __thiscall RMMFAudioPolicyProxy::GetRecordFormat(class TPckgBuf<class RMdaDevSound::TCurrentSoundFormat> &)
	?GetRecordFormatsSupported@RMMFAudioPolicyProxy@@QAEHAAV?$TPckgBuf@VTSoundFormatsSupported@RMdaDevSound@@@@@Z @ 5 NONAME ; public: int __thiscall RMMFAudioPolicyProxy::GetRecordFormatsSupported(class TPckgBuf<class RMdaDevSound::TSoundFormatsSupported> &)
	?LaunchRequests@RMMFAudioPolicyProxy@@QAEHXZ @ 6 NONAME ; public: int __thiscall RMMFAudioPolicyProxy::LaunchRequests(void)
	?MakeRequest@RMMFAudioPolicyProxy@@QAEXAAVTMMFAudioPolicyPrioritySettings@@@Z @ 7 NONAME ; public: void __thiscall RMMFAudioPolicyProxy::MakeRequest(class TMMFAudioPolicyPrioritySettings &)
	?Open@RMMFAudioPolicyProxy@@QAEHAAVRServer2@@@Z @ 8 NONAME ; int RMMFAudioPolicyProxy::Open(class RServer2 &)
	?ReceiveEvents@RMMFAudioPolicyProxy@@QAEXAAV?$TPckgBuf@VTMMFAudioPolicyEvent@@@@AAVTRequestStatus@@@Z @ 9 NONAME ; public: void __thiscall RMMFAudioPolicyProxy::ReceiveEvents(class TPckgBuf<class TMMFAudioPolicyEvent> &,class TRequestStatus &)
	?SetDevSoundInfo@RMMFAudioPolicyProxy@@QAEHAAVTMMFDevSoundInfo@@@Z @ 10 NONAME ; public: int __thiscall RMMFAudioPolicyProxy::SetDevSoundInfo(class TMMFDevSoundInfo &)
	?UpdateState@RMMFAudioPolicyProxy@@QAEHAAVTMMFAudioPolicyPrioritySettings@@@Z @ 11 NONAME ; public: int __thiscall RMMFAudioPolicyProxy::UpdateState(class TMMFAudioPolicyPrioritySettings &)
	?CancelRequestResourceNotification@RMMFAudioPolicyProxy@@QAEHVTUid@@@Z @ 12 NONAME ; int RMMFAudioPolicyProxy::CancelRequestResourceNotification(class TUid)
	?RequestResourceNotification@RMMFAudioPolicyProxy@@QAEHVTUid@@ABVTDesC8@@@Z @ 13 NONAME ; int RMMFAudioPolicyProxy::RequestResourceNotification(class TUid, class TDesC8 const &)
	?StopNotification@RMMFAudioPolicyProxy@@QAEHXZ @ 14 NONAME ; int RMMFAudioPolicyProxy::StopNotification(void)
	?IsRegisteredResourceNotification@RMMFAudioPolicyProxy@@QAEHVTUid@@@Z @ 15 NONAME ; int RMMFAudioPolicyProxy::IsRegisteredResourceNotification(class TUid)
	?CreateServer@RMMFAudioPolicyProxy@@QAEHAAVRServer2@@@Z @ 16 NONAME ; int RMMFAudioPolicyProxy::CreatePolicyServer(class RServer2 &)

